aboutsummaryrefslogtreecommitdiffstats
path: root/src/tests/test_ffi.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tests/test_ffi.cpp')
-rw-r--r--src/tests/test_ffi.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tests/test_ffi.cpp b/src/tests/test_ffi.cpp
index ef9dab2d1..03974589d 100644
--- a/src/tests/test_ffi.cpp
+++ b/src/tests/test_ffi.cpp
@@ -1532,8 +1532,8 @@ class FFI_Unit_Tests final : public Test
}
else
{
- // PBKDF2 currently always rounds to multiple of 10,000
- result.test_eq("Expected PBKDF2 iters", pbkdf_iters_out % 10000, 0);
+ // PBKDF2 currently always rounds to multiple of 2000
+ result.test_eq("Expected PBKDF2 iters", pbkdf_iters_out % 2000, 0);
}
privkey.resize(privkey_len);